@@ -256,12 +256,12 @@ class FileStoreMetadata:
     @staticmethod
     def deserialize(serialized: bytes) -> FileStoreMetadata:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: FileStoreMetadata
         """
         metadata = FileStoreMetadata("a", "a", "a", "", "", "", dict(), False, Timestamp.now(), Timestamp.now())
@@ -270,9 +270,9 @@ class FileStoreMetadata:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -545,12 +545,12 @@ class FileMetadata:
     @staticmethod
     def deserialize(serialized: bytes) -> FileMetadata:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: FileMetadata
         """
         metadata = FileMetadata("a", "a", "a", "", 0, False, Timestamp.now())
@@ -559,9 +559,9 @@ class FileMetadata:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -788,12 +788,12 @@ class FileStoreMetadataRequest:
     @staticmethod
     def deserialize(serialized: bytes) -> FileStoreMetadataRequest:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: FileStoreMetadataRequest
         """
         request = FileStoreMetadataRequest("a", "a", "a", "a")
@@ -802,9 +802,9 @@ class FileStoreMetadataRequest:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -942,12 +942,12 @@ class FileStoreMetadataResponse:
     @staticmethod
     def deserialize(serialized: bytes) -> FileStoreMetadataResponse:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: FileStoreMetadataResponse
         """
         response = FileStoreMetadataResponse(error_code=0, error_message="")
@@ -956,9 +956,9 @@ class FileStoreMetadataResponse:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -1155,12 +1155,12 @@ class FileStoreRequest:
     @staticmethod
     def deserialize(serialized: bytes) -> FileStoreRequest:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: FileStoreRequest
         """
         request = FileStoreRequest("a", "a", "a", "a", "a")
@@ -1169,9 +1169,9 @@ class FileStoreRequest:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -1333,12 +1333,12 @@ class FileStoreResponse:
     @staticmethod
     def deserialize(serialized: bytes) -> FileStoreResponse:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: FileStoreResponse
         """
         response = FileStoreResponse(error_code=0, error_message="")
@@ -1347,9 +1347,9 @@ class FileStoreResponse:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -1550,12 +1550,12 @@ class FileMetadataRequest:
     @staticmethod
     def deserialize(serialized: bytes) -> FileMetadataRequest:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: FileMetadataRequest
         """
         request = FileMetadataRequest("a", "a", "a", "a", "a")
@@ -1565,9 +1565,9 @@ class FileMetadataRequest:
     def _read_proto(self,
                     serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -1722,12 +1722,12 @@ class FileMetadataResponse:
     @staticmethod
     def deserialize(serialized: bytes) -> FileMetadataResponse:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: FileMetadataResponse
         """
         response = FileMetadataResponse(error_code=0, error_message="")
@@ -1737,9 +1737,9 @@ class FileMetadataResponse:
     def _read_proto(self,
                     serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
